# Femos
My small library for neuroevolution

This is my set of classes and functions to build genetic algorithms.
Right now they are specified for evolving neural networks weights.
With this stuff in every new neuroevolution project you can just focus on constructing evaluation function.
